@@ -2,9 +2,11 @@ use strict;
 use warnings;
 
 package Perl::PrereqScanner::Scanner::TestMore;
-BEGIN {
-  $Perl::PrereqScanner::Scanner::TestMore::VERSION = '1.000';
+{
+  $Perl::PrereqScanner::Scanner::TestMore::VERSION = '1.009';
 }
+# ABSTRACT: scanner to find recent Test::More usage
+
 use Moose;
 use List::MoreUtils 'none';
 with 'Perl::PrereqScanner::Scanner';
@@ -24,21 +26,37 @@ sub scan_for_prereqs {
 
 1;
 
-__END__
+
+
 =pod
 
 =head1 NAME
 
-Perl::PrereqScanner::Scanner::TestMore
+Perl::PrereqScanner::Scanner::TestMore - scanner to find recent Test::More usage
 
 =head1 VERSION
 
-version 1.000
+version 1.009
+
+=head1 DESCRIPTION
+
+This scanner will check if a given test is using recent functions from
+L<Test::More>, and increase the minimum version for this module
+accordingly.
 
 =head1 AUTHORS
 
-  Jerome Quelin
-  Ricardo Signes <rjbs@cpan.org>
+=over 4
+
+=item *
+
+Jerome Quelin
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -49,3 +67,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
